@@ -1,4 +1,5 @@
 import logging
+import mimetypes
 import os
 import re
 import sys
@@ -8,6 +9,8 @@ from io import IOBase
 from typing import Union, List, Optional, Dict, DefaultDict, Tuple, BinaryIO
 from urllib.parse import urlencode
 
+from .utils import get_real_file_path
+
 try:
     import jstyleson as json
     from jsonschema import validate
@@ -36,11 +39,7 @@ MIME_TYPE_JSON = "application/json"
 FORM_URLENCODED = "application/x-www-form-urlencoded"
 MULTIPART_FORM_INPUT = "multipart/form-data"
 
-if os.path.exists(__file__):
-    dir_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'http.tx')
-else:
-    dir_path = os.path.join(os.path.dirname(os.path.dirname(os.path.abspath(__file__))), 'http.tx')
-dothttp_model = metamodel_from_file(dir_path)
+dothttp_model = metamodel_from_file(get_real_file_path(path="http.tx", current_file=__file__))
 
 
 def eprint(*args, **kwargs):
@@ -61,6 +60,7 @@ class Config:
     stdout: bool = False
     experimental: bool = False
     target: str = field(default_factory=lambda: '1')
+    content: str = None
 
 
 @dataclass
@@ -86,6 +86,7 @@ class HttpDef:
     auth: Tuple[str] = None
     payload: Optional[Payload] = None
     output: str = None
+    test_script: str = ""
 
     def get_har(self):
         target = {
@@ -173,7 +174,7 @@ class BaseModelProcessor:
             currently environment has restriction to not use "*" and "headers"
         :return:
         """
-        if not self.property_file:
+        if not self.property_file and self.file:
             base_logger.debug('property file not specified')
             default = os.path.join(os.path.dirname(self.file), ".dothttp.json")
             if os.path.exists(default):
@@ -320,6 +321,11 @@ class HttpDefBase(BaseModelProcessor):
             f'computed query params from `{self.file}` are `{params}`')
         self.httpdef.query = params
 
+    def remove_quotes(self, header, s="'"):
+        if header.key.startswith(s) and header.value.endswith(s):
+            header.key = header.key[1:]
+            header.value = header.value[:-1]
+
     def load_headers(self):
         """
             entrypoints
@@ -333,6 +339,8 @@ class HttpDefBase(BaseModelProcessor):
         headers.update(self.default_headers)
         for line in self.http.lines:
             if header := line.header:
+                self.remove_quotes(header, "'")
+                self.remove_quotes(header, '"')
                 headers[self.get_updated_content(header.key)] = self.get_updated_content(header.value)
         request_logger.debug(
             f'computed query params from `{self.file}` are `{headers}`')
@@ -351,7 +359,10 @@ class HttpDefBase(BaseModelProcessor):
             return
         request_logger.debug(
             f'method not defined in `{self.file}`. defaults to `GET`')
-        self.httpdef.method = "GET"
+        if self.http.payload:
+            self.httpdef.method = "POST"
+        else:
+            self.httpdef.method = "GET"
 
     def load_payload(self):
         self.httpdef.payload = self._load_payload()
@@ -370,8 +381,8 @@ class HttpDefBase(BaseModelProcessor):
         # can be short circuted
         if not self.http.payload:
             return Payload()
-        elif self.http.payload.data or self.http.payload.multi:
-            data = self.http.payload.data or self.http.payload.multi[3:-3]
+        elif self.http.payload.data:
+            data = "".join([i.triple[3:-3] if i.triple else i.str for i in self.http.payload.data])
             content = self.get_updated_content(data)
             mimetype = self.get_mimetype_from_buffer(content,
                                                      self.get_updated_content(self.http.payload.type))
@@ -421,9 +432,10 @@ class HttpDefBase(BaseModelProcessor):
         if mimetype:
             return mimetype
         if magic:
-            return magic.from_file(filename, mime=True)
-        else:
-            return None
+            mimetype = magic.from_file(filename, mime=True)
+        elif mimetypes:
+            mimetype = mimetypes.guess_type(filename, strict=False)[0]
+        return mimetype
 
     @staticmethod
     def get_mimetype_from_buffer(data, mimetype: Optional[str]) -> Optional[str]:
@@ -465,4 +477,11 @@ class HttpDefBase(BaseModelProcessor):
         self.load_query()
         self.load_payload()
         self.load_auth()
+        self.load_test_script()
         self._loaded = True
+
+    def load_test_script(self):
+        self.httpdef.test_script = ""
+        if script_wrap := self.http.script_wrap:
+            script = script_wrap.script[4:-2]
+            self.httpdef.test_script = script.strip()
